@@ -2,28 +2,28 @@ from . import components  # noqa
 from .base import *  # noqa
 from .components import *  # noqa
 from .components import button  # noqa
-from .components import checkbox  # noqa
 from .components import content_switcher  # noqa
 from .components import datatable  # noqa
-from .components import form  # noqa
 from .components import grid  # noqa
-from .components import helpers  # noqa
 from .components import icon  # noqa
 from .components import loading  # noqa
 from .components import modal  # noqa
-from .components import multiselect  # noqa
 from .components import notification  # noqa
 from .components import overflow_menu  # noqa
 from .components import pagination  # noqa
 from .components import progress_indicator  # noqa
 from .components import search  # noqa
-from .components import search_select  # noqa
-from .components import select  # noqa
 from .components import shell_header  # noqa
 from .components import sidenav  # noqa
 from .components import tabs  # noqa
 from .components import tag  # noqa
-from .components import text_area  # noqa
-from .components import text_input  # noqa
-from .components import toggle  # noqa
+from .components import forms as form  # noqa # API BACKWARDS COMPATABILITY
+from .components.forms import checkbox  # noqa
+from .components.forms import helpers  # noqa
+from .components.forms import multiselect  # noqa
+from .components.forms import search_select  # noqa
+from .components.forms import select  # noqa
+from .components.forms import text_area  # noqa
+from .components.forms import text_input  # noqa
+from .components.forms import toggle  # noqa
 from .skeleton import *  # noqa
