@@ -1,9 +1,10 @@
+import django_celery_results.models
 from django.contrib.messages.views import SuccessMessageMixin
 from django.urls import include, path
 from dynamic_preferences import views as preferences_views
 from dynamic_preferences.registries import global_preferences_registry
 
-from bread.utils import autopath
+from bread.utils import autopath, default_model_paths
 
 from .forms.forms import PreferencesForm
 from .views import admin, auth, system, userprofile
@@ -14,7 +15,6 @@ PreferencesView = type(
     {"success_message": "Preferences updated"},
 )
 
-
 external_urlpatterns = [
     path("ckeditor/", include("ckeditor_uploader.urls")),
     path(
@@ -46,12 +46,22 @@ external_urlpatterns = [
     ),
 ]
 
-
 urlpatterns = [
-    path("auth/", include("django.contrib.auth.urls")),
-    path("accounts/login/", auth.BreadLoginView.as_view(), name="login"),
-    path("accounts/logout/", auth.BreadLogoutView.as_view(), name="logout"),
-    path("accounts/user/", userprofile.UserProfileView.as_view(), name="userprofile"),
+    path(
+        "accounts/login/",
+        auth.BreadLoginView.as_view(),
+        name="login",
+    ),
+    path(
+        "accounts/logout/",
+        auth.BreadLogoutView.as_view(),
+        name="logout",
+    ),
+    path(
+        "accounts/user/",
+        userprofile.UserProfileView.as_view(),
+        name="userprofile",
+    ),
     autopath(
         userprofile.EditPersonalDataView.as_view(), urlname="userprofile.personal"
     ),
@@ -83,7 +93,8 @@ urlpatterns = [
     ),
     path("systeminformation", system.systeminformation, name="systeminformation"),
     path("admin/maintenance", admin.maintenancesettings, name="breadadmin.maintenance"),
-    path(
-        "admin/backgroundjobs", admin.backgroundjobs, name="breadadmin.backgroundjobs"
+    *default_model_paths(
+        django_celery_results.models.TaskResult,
+        browseview=admin.TaskResultBrowseView,
     ),
 ] + external_urlpatterns
